@@ -5,6 +5,8 @@
 
 # WARNING: do not import unnecessary things here to keep cli startup time under
 # control
+import logging
+
 import click
 
 from swh.core.cli import CONTEXT_SETTINGS
@@ -16,7 +18,10 @@ from swh.core.cli import swh as swh_cli_group
     "--config-file",
     "-C",
     default=None,
-    type=click.Path(exists=True, dir_okay=False,),
+    type=click.Path(
+        exists=True,
+        dir_okay=False,
+    ),
     help="Configuration file.",
 )
 @click.pass_context
@@ -40,6 +45,41 @@ def initialize(ctx):
     print("Done.")
 
 
+@search_cli_group.command(name="rpc-serve")
+@click.option(
+    "--host",
+    default="0.0.0.0",
+    metavar="IP",
+    show_default=True,
+    help="Host ip address to bind the server on",
+)
+@click.option(
+    "--port",
+    default=5010,
+    type=click.INT,
+    metavar="PORT",
+    show_default=True,
+    help="Binding port of the server",
+)
+@click.option(
+    "--debug/--no-debug",
+    default=True,
+    help="Indicates if the server should run in debug mode",
+)
+@click.pass_context
+def serve(ctx, host, port, debug):
+    """Software Heritage Storage RPC server.
+
+    Do NOT use this in a production environment.
+    """
+    from swh.search.api.server import app
+
+    if "log_level" in ctx.obj:
+        logging.getLogger("werkzeug").setLevel(ctx.obj["log_level"])
+    app.config.update(ctx.obj["config"])
+    app.run(host, port=int(port), debug=bool(debug))
+
+
 @search_cli_group.group("journal-client")
 @click.pass_context
 def journal_client(ctx):
@@ -62,7 +102,9 @@ def journal_client(ctx):
     help="Default list of object types to subscribe to",
 )
 @click.option(
-    "--prefix", "-p", help="Topic prefix to use (e.g swh.journal.indexed)",
+    "--prefix",
+    "-p",
+    help="Topic prefix to use (e.g swh.journal.indexed)",
 )
 @click.pass_context
 def journal_client_objects(ctx, stop_after_objects, object_type, prefix):
@@ -74,6 +116,7 @@ def journal_client_objects(ctx, stop_after_objects, object_type, prefix):
     import functools
 
     from swh.journal.client import get_journal_client
+    from swh.storage import get_storage
 
     from . import get_search
     from .journal_client import process_journal_objects
@@ -93,10 +136,16 @@ def journal_client_objects(ctx, stop_after_objects, object_type, prefix):
     if journal_cfg["prefix"] is None:
         raise ValueError("'prefix' must be specified by cli or configuration")
 
-    client = get_journal_client(cls="kafka", **journal_cfg,)
+    client = get_journal_client(
+        cls="kafka",
+        **journal_cfg,
+    )
     search = get_search(**config["search"])
+    storage = get_storage(**config["storage"])
 
-    worker_fn = functools.partial(process_journal_objects, search=search,)
+    worker_fn = functools.partial(
+        process_journal_objects, search=search, storage=storage
+    )
     nb_messages = 0
     try:
         nb_messages = client.process(worker_fn)
@@ -107,24 +156,3 @@ def journal_client_objects(ctx, stop_after_objects, object_type, prefix):
         print("Done.")
     finally:
         client.close()
-
-
-@search_cli_group.command("rpc-serve")
-@click.argument("config-path", required=True)
-@click.option("--host", default="0.0.0.0", help="Host to run the server")
-@click.option("--port", default=5010, type=click.INT, help="Binding port of the server")
-@click.option(
-    "--index-prefix", required=False, help="The prefix to add before the index names"
-)
-@click.option(
-    "--debug/--nodebug",
-    default=True,
-    help="Indicates if the server should run in debug mode",
-)
-def rpc_server(config_path, host, port, index_prefix, debug):
-    """Starts a Software Heritage Indexer RPC HTTP server."""
-    from .api.server import app, load_and_check_config
-
-    api_cfg = load_and_check_config(config_path, type="any")
-    app.config.update(api_cfg)
-    app.run(host, port=int(port), index_prefix=index_prefix, debug=bool(debug))
