@@ -1,13 +1,13 @@
-# Copyright (C) 2019-2022  The Software Heritage developers
+# Copyright (C) 2019-2023  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
 from collections import Counter
 from datetime import datetime, timedelta, timezone
+import hashlib
 from itertools import permutations
 
-from hypothesis import given, settings, strategies
 import pytest
 
 from swh.core.api.classes import stream_results
@@ -1105,10 +1105,8 @@ class CommonSearchTest:
 
     # TODO: add more tests with edge cases
 
-    @settings(deadline=None)
-    @given(strategies.integers(min_value=1, max_value=4))
+    @pytest.mark.parametrize("limit", list(range(1, 5)))
     def test_origin_url_paging(self, limit):
-        # TODO: no hypothesis
         origin1_foo = {"url": "http://origin1/foo"}
         origin2_foobar = {"url": "http://origin2/foo/bar"}
         origin3_foobarbaz = {"url": "http://origin3/foo/bar/baz"}
@@ -1140,10 +1138,8 @@ class CommonSearchTest:
         ]
         assert sorted(results[0 : len(expected_results)]) == sorted(expected_results)
 
-    @settings(deadline=None)
-    @given(strategies.integers(min_value=1, max_value=4))
+    @pytest.mark.parametrize("limit", list(range(1, 5)))
     def test_origin_jsonld_paging(self, limit):
-        # TODO: no hypothesis
         origin1_foo = {"url": "http://origin1"}
         origin2_foobar = {"url": "http://origin2"}
         origin3_foobarbaz = {"url": "http://origin3"}
@@ -1227,7 +1223,7 @@ class CommonSearchTest:
         assert result_page.next_page_token is None
         assert result_page.results == []
 
-    def test_filter_keyword_in_filter(self):
+    def test_search_filter_keyword_in_filter(self):
         origin1 = {
             "url": "foo language in ['foo baz'] bar",
         }
@@ -1242,6 +1238,94 @@ class CommonSearchTest:
         assert result_page.next_page_token is None
         assert result_page.results == []
 
+    def test_origin_get(self):
+        """Checks the same field can have a concrete value, an object, or an array
+        in different documents."""
+        origin1 = {"url": "http://origin1"}
+        origin2 = {"url": "http://origin2"}
+        origin3 = {"url": "http://origin3"}
+        origins = [
+            {
+                **origin1,
+                "jsonld": {
+                    "@context": "https://doi.org/10.5063/schema/codemeta-2.0",
+                    "author": {
+                        "familyName": "Foo",
+                        "givenName": "Bar",
+                    },
+                },
+            },
+            {
+                **origin2,
+                "jsonld": {
+                    "@context": "https://doi.org/10.5063/schema/codemeta-2.0",
+                    "author": "Bar Baz",
+                },
+            },
+            {
+                **origin3,
+                "jsonld": {
+                    "@context": "https://doi.org/10.5063/schema/codemeta-2.0",
+                    "author": ["Baz", "Qux"],
+                },
+            },
+        ]
+
+        expanded_origins = [
+            {
+                **origin1,
+                "sha1": hashlib.sha1(origin1["url"].encode()).hexdigest(),
+                "jsonld": [
+                    {
+                        "http://schema.org/author": [
+                            {
+                                "@list": [
+                                    {
+                                        "http://schema.org/familyName": [
+                                            {"@value": "Foo"}
+                                        ],
+                                        "http://schema.org/givenName": [
+                                            {"@value": "Bar"}
+                                        ],
+                                    }
+                                ]
+                            }
+                        ],
+                    }
+                ],
+            },
+            {
+                **origin2,
+                "sha1": hashlib.sha1(origin2["url"].encode()).hexdigest(),
+                "jsonld": [
+                    {
+                        "http://schema.org/author": [
+                            {"@list": [{"@value": "Bar Baz"}]}
+                        ],
+                    }
+                ],
+            },
+            {
+                **origin3,
+                "sha1": hashlib.sha1(origin3["url"].encode()).hexdigest(),
+                "jsonld": [
+                    {
+                        "http://schema.org/author": [
+                            {"@list": [{"@value": "Baz"}, {"@value": "Qux"}]}
+                        ],
+                    }
+                ],
+            },
+        ]
+
+        self.search.origin_update(origins)
+        self.search.flush()
+
+        assert self.search.origin_get(origin1["url"]) == expanded_origins[0]
+        assert self.search.origin_get(origin2["url"]) == expanded_origins[1]
+        assert self.search.origin_get(origin3["url"]) == expanded_origins[2]
+        assert self.search.origin_get("http://origin4") is None
+
     def test_visit_types_count(self):
         assert self.search.visit_types_count() == Counter()
 
